package cc.smtweb.system.bpm.web.engine.model.listcard.normal;

import cc.smtweb.framework.core.cache.AbstractCache;
import cc.smtweb.framework.core.cache.CacheManager;
import cc.smtweb.framework.core.common.R;
import cc.smtweb.framework.core.db.DbEngine;
import cc.smtweb.framework.core.db.EntityDao;
import cc.smtweb.framework.core.db.cache.ModelTableCache;
import cc.smtweb.framework.core.db.jdbc.AbsDbWorker;
import cc.smtweb.framework.core.db.vo.ModelTable;
import cc.smtweb.framework.core.exception.BizException;
import cc.smtweb.system.bpm.web.design.form.define.PageDataset;
import cc.smtweb.system.bpm.web.engine.model.listcard.single.LCSingleDelHandler;
import org.springframework.util.Assert;

/**
 * Created by Akmm at 2022/4/21 17:53
 * 删除操作
 */
public class LCNormalDelHandler extends LCSingleDelHandler {
    /**
     * 删除指定数据集，入参{pageId, dataset, id}
     *
     * @return
     */
    public R del() {
        long id = params.readLong("id");
        if (id == 0L) throw new BizException("没有收到待删除记录Id(" + id + ")！");
        //数据集
        String dataSet = params.readString("dataset");
        PageDataset delDataSet = this.datasets.findByName(dataSet);
        Assert.notNull(delDataSet,"未获取到数据集:"+dataSet);
        //
        checkBean(delDataSet, id);
        //
        DbEngine.getInstance().doTrans(new AbsDbWorker() {
            @Override
            public void work() {
                ModelTable table = ModelTableCache.getInstance().get(delDataSet.masterTable);
                if (table == null) throw new BizException("没有找到指定的的表定义：" + delDataSet.name + "！");
                EntityDao dao = DbEngine.getInstance().findDao(table.getName());
                dao.deleteEntity(id);
                localDel(id, table);
            }

            @Override
            public void doAfterDbCommit() {
                ModelTable table = ModelTableCache.getInstance().get(delDataSet.masterTable);
                if (table.isNeedCache()) {
                    AbstractCache cache = CacheManager.getIntance().getCache(table.getName());
                    cache.remove(id);
                }
                localDelSuccess(id, table);
            }
        });
        return R.success();
    }
}
